@@ -8,15 +8,7 @@
 *
 ********************************************************************************
 *
-* $Project: /Convert-Binary-C $
-* $Author: mhx $
-* $Date: 2011/04/10 12:32:30 +0200 $
-* $Revision: 24 $
-* $Source: /ucpp/config.h $
-*
-********************************************************************************
-*
-* Copyright (c) 2002-2011 Marcus Holland-Moritz. All rights reserved.
+* Copyright (c) 2002-2015 Marcus Holland-Moritz. All rights reserved.
 * This program is free software; you can redistribute it and/or modify
 * it under the same terms as Perl itself.
 *
@@ -96,6 +88,18 @@
 
 #include <stdlib.h>
 
+/*
+ * Under some circumstances, setjmp() on Win64 does deadlock when the
+ * memory containing the jmpbuf was allocated through the Perl API.
+ *
+ * Apparently, using standard malloc/free fixes the deadlock, yet I
+ * don't have any explanation for what's really going on.
+ *
+ * I'll appreciate any enlightenment. :-)
+ */
+
+#ifndef _WIN64 
+
 extern void *CBC_malloc(size_t size);
 extern void *CBC_realloc(void *ptr, size_t size);
 extern void  CBC_free(void *ptr);
@@ -104,6 +108,8 @@ extern void  CBC_free(void *ptr);
 #define UCPP_REALLOC  CBC_realloc
 #define UCPP_FREE     CBC_free
 
+#endif
+
 /*-------------*/
 /* other stuff */
 /*-------------*/
